write

Function write 

pub(crate) unsafe fn write<Float>(value: Float, buffer: *mut u8) -> *mut u8
where Float: FloatTraits,
Writes the shortest correctly rounded decimal representation of value to buffer. buffer should point to a buffer of size buffer_size or larger.